**************************************************************************************************
*** This do file creates the database for 
*** 																		*/
**************************************************************************************************
*** Last update: February 06, 2011 AD
**************************************************************************************************
/* Note: This do file consists of 3 parts. The first part manipulates some original data 		*/
/* and stores them in new files in the directory "/bearbeitet"; the second merges the stata 	*/
/* files and stores them in the file "PPP database complete.dta" in the		 					*/
/* directory "/bearbeitet"; the third part contains the analysis and exports the tables 		*/
/* in the directory "tables" where the log file is also stored. Results for the EBA are stored 	*/
/* in the folder "EBA".																			*/
/* You have to change "local DIR" to the directory you copy the original stata files contained 	*/
/* in the zip file and then run the do file. 													*/
**************************************************************************************************
version 11.0
drop _all
clear matrix
clear mata
set mem 800m
set mat 500

capture net install mfx2, from(http://fmwww.bc.edu/RePEc/bocode/m)			/* checks whether mfx2 is installed 		*/
capture net install egenmore, from(http://fmwww.bc.edu/RePEc/bocode/e)		/* checks whether egenmore is installed		*/
capture net install estout, from(http://fmwww.bc.edu/RePEc/bocode/e)		/* checks whether estout is installed		*/
capture net install spmon, from(http://fmwww.bc.edu/RePEc/bocode/s)			/* checks whether spmon is installed		*/
capture net install mmerge, from(http://fmwww.bc.edu/RePEc/bocode/m)		/* checks whether mmerge is installed		*/
capture net install msp, from(http://fmwww.bc.edu/RePEc/bocode/m)			/* checks whether msp is installed			*/


***********************************************************************************
local DIR = "C:\Users\gehringk\Documents\Forschung\Dezentralisierung\Daten\Stata" /*change relative path to the directory where the files are located */
*local DIR = "Z:\Neuer Ordner\Forschung\Dezentralisierung\Daten\Stata" /*change relative path to the directory where the files are located */

	cd "`DIR'"
	***********************************************************************************
	set more off

	*** checks whether folder "bearbeitet" (where transformed data are stored) and "tables" (where tables are stored) exist and creates it if not
	program define confirmdir, rclass
		local cwd `"`c(pwd)'"'
		quietly capture cd `"`1'"'
		local confirmdir=_rc 
		quietly cd `"`cwd'"'
		return local confirmdir `"`confirmdir'"'
	end 
		confirmdir `"bearbeitet"'	  	/* does folder "bearbeitet" exist? */
			if `r(confirmdir)'!=0  {  	/* folder does not yet exist */
				mkdir "bearbeitet"  	/* makes the folder  */
							  } 
			  else {
				di "folder bearbeitet already exists"
				}
		confirmdir `"tables"'		  /* does folder "tables" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "tables"  /* makes the folder  */
							  } 
			  else {
				di "folder tables already exists"
				}
		confirmdir `"EBA"'		  /* does folder "EBA" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "EBA"  /* makes the folder  */
							  } 
			  else {
				di "folder EBA already exists"
				}
	program drop confirmdir


	log using "tables\Dreher, Ko, Geh and Sab.log", replace

	*******************************************************************************************************************
	************* PART 1: Manipulate some data
	*******************************************************************************************************************

	*** IMF government finance statistics, Spring 2012, Panel data
	*** Variables Included: 
	** Key: So far only 3-digit World Bank country code, added three letter country code CCode and year
	*

	use "IMF_GFS.dta",clear
	merge m:m COUNTRY_CODE using "CountryCode.dta"  //Add three letter country code as key
	drop if _merge!=3
	drop _merge
	ren ccode CCode
	order CCode, before( COUNTRY_CODE)
	ren COUNTRY_NAME country
	ren  I1972  i1972
	ren  I1973 i1973
	ren  I1974 i1974
	ren  I1975 i1975
	ren  I1976 i1976
	ren  I1977 i1977
	ren  I1978 i1978
	ren  I1979 i1979
	ren  I1980 i1980
	ren  I1981 i1981
	ren  I1982 i1982
	ren  I1983 i1983
	ren  I1984 i1984
	ren  I1985 i1985
	ren  I1986 i1986
	ren  I1987 i1987
	ren  I1988 i1988
	ren  I1989 i1989
	ren  I1990 i1990
	ren  I1991 i1991
	ren  I1992 i1992
	ren  I1993 i1993
	ren  I1994 i1994
	ren  I1995 i1995
	ren  I1996 i1996
	ren  I1997 i1997
	ren  I1998 i1998
	ren  I1999 i1999
	ren  I2000 i2000
	ren  I2001 i2001
	ren  I2002 i2002
	ren  I2003 i2003
	ren  I2004 i2004
	ren  I2005 i2005
	ren  I2006 i2006
	ren  I2007 i2007
	ren  I2008 i2008
	ren  I2009 i2009
	ren  I2010 i2010
	ren  I2011 i2011
	ren  I2012 i2012
	reshape long i, i(COUNTRY_CODE DESCRIPTOR GOVERNMENT_LEVEL) j(year)
	*Now calculate ratios before reshaping. 
	encode DESCRIPTOR,generate(descriptor) label(DESCRIPTOR)  //Create numerical variable for descriptor variables
	encode GOVERNMENT_LEVEL, gen(gov_level) label(GOVERNMENT_LEVEL) //(Generate numerical variable for government levels)
	tostring descriptor, gen(Descriptor)   //Need new variable without blanks to reshape
	gen Var= Descriptor+ GOVERNMENT_LEVEL
	*label save DESCRIPTOR using label  //save label to rename the variables later. Copy label to excel file rename.xls to get the code for renaming
	label list DESCRIPTOR


	drop DESCRIPTOR GOVERNMENT_LEVEL SERIES_CODE descriptor Descriptor gov_level

	*After reshape we want to keep 4 number per country and year
	reshape wide i, i(country COUNTRY_CODE CCode year) j(Var) string
	label var i1GG "Compensation of employees
	label var i2GG "Consumption of fixed capital
	label var i3GG "Exp_Grants
	label var i4GG "Expense
	label var i5GG "Grants
	label var i6GG "Grants from general government units
	label var i7GG "Grants to general government units
	label var i8GG "Interest
	*label var i9GG "Interest to other general government units
	label var i10GG "Other expense
	label var i11GG "Other revenue
	label var i12GG "Other taxes
	label var i13GG "Revenue
	label var i14GG "Social benefits
	label var i15GG "Social contributions
	label var i16GG "Subsidies
	label var i17GG "Taxes
	label var i18GG "Taxes on goods and services
	label var i19GG "Taxes on income, profits, and capital gains
	label var i20GG "Taxes on international trade and transactions
	label var i21GG "Taxes on payroll and workforce
	label var i22GG "Taxes on property
	label var i23GG "Use of goods and services
	label var i1LG "Compensation of employees
	label var i2LG "Consumption of fixed capital
	label var i3LG "Exp_Grants
	label var i4LG "Expense
	label var i5LG "Grants
	label var  i6LG "Grants from general government units
	label var  i7LG "Grants to general government units
	label var  i8LG "Interest
	label var  i9LG "Interest to other general government units
	label var  i10LG "Other expense
	label var  i11LG "Other revenue
	label var  i12LG "Other taxes
	label var  i13LG "Revenue
	label var  i14LG "Social benefits
	label var  i15LG "Social contributions
	label var  i16LG "Subsidies
	label var  i17LG "Taxes
	label var  i18LG "Taxes on goods and services
	label var  i19LG "Taxes on income, profits, and capital gains
	label var  i20LG "Taxes on international trade and transactions
	label var  i21LG "Taxes on payroll and workforce
	label var  i22LG "Taxes on property
	label var  i23LG "Use of goods and services
	label var  i1SG "Compensation of employees
	label var  i2SG "Consumption of fixed capital
	label var  i3SG "Exp_Grants
	label var  i4SG "Expense
	label var  i5SG "Grants
	label var  i6SG "Grants from general government units
	label var  i7SG "Grants to general government units
	label var  i8SG "Interest
	label var  i9SG "Interest to other general government units
	label var  i10SG "Other expense
	*label var  i11SG "Other revenue
	label var  i12SG "Other taxes
	label var  i13SG "Revenue
	*label var  i14SG "Social benefits
	label var  i15SG "Social contributions
	label var  i16SG "Subsidies
	label var  i17SG "Taxes
	label var  i18SG "Taxes on goods and services
	label var  i19SG "Taxes on income, profits, and capital gains
	label var  i20SG "Taxes on international trade and transactions
	label var  i21SG "Taxes on payroll and workforce
	label var  i22SG "Taxes on property
	label var  i23SG "Use of goods and services
	*********************************************
	*create Decentralization variables
	*1.Sub-national expenditures (% of total expenditures)
	*Theoretically possible to deduct interest payments as well, but might be incorret
	* 1st Choice: Interest payments are not deducted
	gen Sub_Exp= (i4LG- i7LG   +   i4SG - i7SG) / (i4GG)
	replace Sub_Exp= (i4LG- i7LG+i4SG ) / (i4GG) if    i7SG==. 
	replace Sub_Exp= (i4LG- i7LG ) / (i4GG) if   i4SG==. &  i7SG==. 
	 replace Sub_Exp= (i4LG +i4SG ) / (i4GG) if   i7SG==. & i7LG==.
	 /*gen Sub_Exp= (i4LG- i7LG- i9LG   +   i4SG - i7SG- i9SG ) / (i4GG)
	*Insert values where there is no state level
	replace Sub_Exp= (i4LG- i7LG- i9LG+i4SG-i7SG ) / (i4GG) if   i9SG==.
	replace Sub_Exp= (i4LG- i7LG- i9LG+i4SG-i9SG ) / (i4GG) if    i7SG==. 
	replace Sub_Exp= (i4LG- i7LG- i9LG+i4SG ) / (i4GG) if    i7SG==. | i9SG==.
	replace Sub_Exp= (i4LG- i7LG- i9LG) / (i4GG) if   i4SG==. |  i7SG==. | i9SG==.
	*Insert value for missing interest or grant payments
	replace Sub_Exp= (i4LG- i7LG) / (i4GG) if   i4SG==. &i9LG==.|  i7SG==. &i9LG==.| i9SG==. &i9LG==.
	replace Sub_Exp= (i4LG- i9LG) / (i4GG) if   i4SG==. &i7LG==.|  i7SG==. &i7LG==.| i9SG==. &i7LG==.
	replace Sub_Exp= (i4LG) / (i4GG) if   i4SG==. &i7LG==.&i9LG==.|  i7SG==. &i7LG==.&i9LG==.| i9SG==. &i7LG==.&i9LG==. */
	*2. Sub-national revenues (% of total revenues)
	gen SubRev=( i13LG+ i13SG)/ i13GG
	replace SubRev=( i13LG)/ i13GG if i13SG
	*3. Vertical Imbalance (%) - To which degree of their expenditure do decentral units depend on grants from other levels (incorrect when transfer from state to local or vice versa
	*I.e. it could be that states transfer money to locals and not to the central government
	gen VerIm= (i17LG+ i17SG)/( i13LG+ i13SG)
	replace VerIm= (i17LG)/( i13LG+ i13SG) if  i17SG==.
	replace  VerIm= (i17LG)/( i13LG) if  i13SG==.
	*4. Tax Effort: Share of taxes that is collected by decentral units
	gen AllTaxes= ( i17LG+ i17SG )/(i17GG)
	replace  AllTaxes= (i17LG )/( i17GG)  if    i17SG==. 
	*replace AllTaxes= ( i17LG+ i17SG +i15LG)/( i15GG+ i17GG) if i15SG==.
	*replace  AllTaxes= (i17LG +i15LG )/( i15GG+ i17GG)  if    i17SG==. &i15SG==.
	*replace  AllTaxes= (i17LG +i15LG )/( i15GG+ i17GG)  if    i17SG==. &i15SG==.
	*replace  AllTaxes= (i17LG )/( i15GG+ i17GG)  if    i17SG==. &i15SG==. &i15LG==.
	*5. Share of compensation of employees that is paid for by decentral units
	gen Employees=(i1LG +i1SG)/ (i1GG)
	replace Employees=(i1LG )/ (i1GG) if i1SG==.
	keep Sub_Exp SubRev VerIm AllTaxes Employees year CCode
	sort CCode year
	foreach Var of varlist Sub_Exp SubRev VerIm AllTaxes Employees{
	replace `Var' = `Var'*100
	}
	sum Employees AllTaxes VerIm SubRev Sub_Exp

	saveold "bearbeitet\IMF_GFS.dta", replace
	clear
	***Eurostat data, 2012, accessed 04.10.2012 at http://epp.eurostat.ec.europa.eu/portal/page/portal/government_finance_statistics/data/database
	***Additional data for the first two decentralization measures for the EU countries after 2000
	***Key variable for merging: Three letter country code as "CCode" and "year"
	import excel "Eurostat2.xls", sheet("SubRev") firstrow
	reshape long y, i( CCode) j(year)
	ren y SubRevEuro
	drop GEOTIME
	replace SubRevEuro=SubRevEuro*100
	replace SubRevEuro=. if SubRevEuro==0
	save "Eurostat1.dta",replace
	clear
	import excel "Eurostat2.xls", sheet("Sub_Exp") firstrow
	reshape long y, i( CCode) j(year)
	ren y Sub_ExpEuro
	replace Sub_ExpEuro=Sub_ExpEuro*100
	replace Sub_ExpEuro=. if Sub_ExpEuro==0
	drop GEOTIME
	save "Eurostat2.dta",replace
	use  "bearbeitet\IMF_GFS.dta", clear
	merge m:m CCode year using "Eurostat1.dta"
	drop if _merge==2
	drop _merge
	replace SubRev=SubRevEuro if SubRevEuro!=.
	gen D_EurostatRev=0
	replace D_EurostatRev=1 if  SubRevEuro!=.
	merge m:m CCode year using "Eurostat2.dta"
	drop if _merge==2
	drop _merge
	replace Sub_Exp=Sub_ExpEuro if Sub_ExpEuro!=.
	gen D_EurostatExp=0
	replace D_EurostatExp=1 if  Sub_ExpEuro!=.
	drop SubRevEuro Sub_ExpEuro
	saveold "bearbeitet\IMF_GFS.dta", replace




	*** Fisman data, data 2002, availability 2002. cross-section
	/*** Variables Included:
		wbcode govshare corrup cenexp cenrev lrypc pop laam safrica asiae civil colaut colbel coldeu coldnk colesp colfra colgbr colita coljpn 
		colnld colprt colusa leg_uk leg_fr leg_so leg_ge leg_sc wco gcor open fraction
		Data on expenditure and revenue decentralization with some controls, not labeled. Are labels available, Axel?
		Contains data on legal and colonial origin*/
	***Key variable for merging: Three letter country code as "CCode" and "year"
	use "decentral_data fisman.dta", clear
	ren wbcode CCode
	gen year=2002
	move year govshare
	***Keep only the data for legal origin and colonial heritage
	keep CCode year leg_uk leg_fr leg_so leg_ge leg_sc colaut colbel coldeu coldnk colesp colfra colgbr colita coljpn colnld colprt colusa
	save "bearbeitet\Fisman.dta", replace
	******************************************************************************************************************************************

	*** Treisman, Treisman 2007, availability (mid 1990s, averages, 81 countries), cross-section
	/***Data on fiscal, administrative and political decentralization: Sources for variables in Fan et al. 2009, Political Decentralization and corruption, only cross section
	***Original data set includes objective corruption reports with about 100 observations per country, we need only one per country. All decentralization variables are averaged over the 1990's
	***Relevant Variables included: g*/
	**Key variable for merging: Three Letter country code as "Ccode" */
	use "Treisman 2007.dta", clear
	gen year=2002
	move year country
	*Keep only one observation per country, the decentralization variables are all constant for one country
	bysort countryname : gen Limit=_n
	keep if Limit==1
	***Rename some variables for clarification
	ren legor Legalorigin
	***Drop all corruption variables not related to our research
	drop ori_estb o_priv r_now gvt_pct ps_pct vsal vfas competitor ladv_ch tlg_days coll papr hint spcn lckm acfk acnb expf lesf crd afs_yn ias_yn mny_day sector cmpt_maj ///
	size_f industrydummy exp_pct exp_yn frk_pct yr_estb foreigndum gvt_yn op_ctry corr t_smgt sdpy concat law_pred av_lreg int_lrg fi_crt hu_crt q_crt aff_crt cst_crt enf_crt cf_crt ///
	cf3_crt gcf infr gcpi infl exr scri ocri txreg gcorr apay pssale hld_123 tadm_reg off_sr telpy licpy taxpy conpy cuspy region1 qcbk adpy corctn_g bri_ptr gvoc_ch lc fmny_dy ltloan ///
	juds antcomp vdebt inta_yn apay_xtr crtpy lawpy othpy nflc_exe nflc_leg nflc_min nflc_reg eco_pred fin_ob1 cmph cmpi fhq_cty salf_iod electpy salf_iud age agecat logsales logfixasset ///
	logfirmage  log_settler_mortality TIcorrupt ti2000 logpepden1500 subemployeenum cenemployeenum corruptdum corrgroup foreigndumtrun y courtbri subgemppop cgemppop Limit licenbri taxbri ///
	contractbri telbri cusbri corruptfre faircourt enforceability uphold quickcourt corruptobstacle Y prot00 fuel00 cr pcr pb info pstring divindex cgovind4 ercmon y1 country ///
	gdppsqr gdppc95 popunit population98 cenemptolabor logavegdpcapita WBcorrupt00 corruptmean pubilcempl toptax poliright illiteracy ethnic school autressizerev policesizebot ///
	roadlocalsizebot tiersshared autressizebot fedsizebot fiscemp pbage pcrage subrevshare formercolony source democratic46yr telcorrupt fiscalrevgdp surfacearea corrupt98 law98 ///
	regulate98 effective98 stable98 voice98 leg_british gdppp99 lngdpp99 alldem00 presdpi fh_press yearopen imp2000 procdj timedj autressize botelautres subrevgdp1 pc_gdp lncdays ///
	govrevgdp shared roadlocal policelocal roadregion policeregion britcol
	*Label variables from Fan et al. Paper 2009, detailed in working paper on Treisman's Homepage
	label variable primary_education "subnational government ovolved in primary education"
	label variable infrastructure "subnational government ovolved in infrastructure"
	label variable policing "subnational government ovolved in policing"
	label variable fedelupd `"Dummy, classified as "federal" by Elazar 1995),with updates: Bosnia and "'
	label variable fedelaz `"Dummy, classified as "federal" by Elazar (Publius, 1995)"'
	**Update manually
	
	rename code CCode
	label variable CCode "3letter Country Code"
	save "bearbeitet\Treisman.dta", replace
	******************************************************************************************************************************************

	*** Kolo Delf Country data, 2012, 210 countries for one point in time, cross-section(time-invariant)
	*** Data on ethnic fractionalization for 210 countries, from Phillip Kolo, univerisity of Gttingen
	**Key variable for merging: Three Letter country code as "Ccode" */
	** There are fractionalization variables for the areas geography, language, ethnic and religion, and a composite index variable delf
	use "DELF Country data",clear
	rename abbr CCode
	label variable CCode "3letter Country Code"
	*keep only relevant indices to maintainb clarity
	keep CCode wcdcountry mastercountry fearonregion groups delf delf_Partc delf_Geo delf_language delf_ethnic delf_religion
	***
	save "bearbeitet\DELF Country data.dta", replace
	******************************************************************************************************************************************

	*** WDI missing indicator data, all data (WDI 2012)
	use "WDI all", clear
	bysort code: count 
	gen var_count=r(N) /* contains total number of series per country */

	foreach year in 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969          ///
																	1970 1971 1972 1973 1974 1975 1976 1977 1978 1979          ///
																	1980 1981 1982 1983 1984 1985 1986 1987 1988 1989          ///
																	1990 1991 1992 1993 1994 1995 1996 1997 1998 1999          ///
																	2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 {

																	bysort code: egen c_`year'=count(_`year')
	}

	bysort code: keep if code~=code[_n-1]
	drop series scode _*

	reshape long c_, i(code) j(year) /* reshape to long format */
	gen missing=c_/var_count          
	label var missing "Missing data, all indicators in WDI 2012"
	drop c_ var_count

	replace code="ROU" if code=="ROM" /* Romania */
	replace code="COD" if code=="ZAR" /* Congo, Dem. Rep. */
	replace code="AND" if code=="ADO" /* Andorra */
	replace code="IMN" if code=="IMY" /* Isle of Man */ 
	replace code="TLS" if code=="TMP" /* Timor Leste */
	replace code="PSE" if code=="WBG" /* West Bank and Gaza */
	ren code CCode
	sort CCode year
	label var missing "Missing WDI data based on four indicators"
	saveold "bearbeitet\missing.dta", replace


	*** WDI missing indicator data, four indicators (WDI 2012)
	use "WDI all", clear
	keep if scode=="FP.CPI.TOTL.ZG" | scode=="NY.GDY.TOTL.KN" | scode=="BN.CAB.XOKA.GD.ZS" | scode=="GC.BAL.CASH.GD.ZS"

	foreach year in 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969          ///
																	1970 1971 1972 1973 1974 1975 1976 1977 1978 1979          ///
																	1980 1981 1982 1983 1984 1985 1986 1987 1988 1989          ///
																	1990 1991 1992 1993 1994 1995 1996 1997 1998 1999          ///
																	2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 {

																	bysort code: egen c_`year'=count(_`year')
	}

	bysort code: keep if code~=code[_n-1]
	drop series scode _*

	reshape long c_, i(code) j(year) /* reshape to long format */
	gen missing_4=c_/4        
	label var missing_4 "Missing data, 4 indicators (Inflation, GDI, CAB, Cash Surplus)"
	drop c_

	replace code="ROU" if code=="ROM" /* Romania */
	replace code="COD" if code=="ZAR" /* Congo, Dem. Rep. */
	replace code="AND" if code=="ADO" /* Andorra */
	replace code="IMN" if code=="IMY" /* Isle of Man */ 
	replace code="TLS" if code=="TMP" /* Timor Leste */
	replace code="PSE" if code=="WBG" /* West Bank and Gaza */

	sort code year
	ren code CCode
	sort CCode year
	label var missing_4 "Missing WDI data based on four indicators"
	saveold "bearbeitet\missing_4.dta", replace



	*** Worldbank data, 2012, 211 countries 1970-2010, panel structure
	*** Data on all variables from the Worldbank that might be relevant regarding complexity, capacity or information
	***Can be easily changed to use other indicators
	***Key variable for merging: Three letter country code as "CCode" and "year"
	use "WorldbankIndicators.dta",clear
	rename countrycode CCode
	rename countryname country
	***Reshape the data to the correct format
	reshape long v, i(country CCode i) j(year)
	drop seriescode seriesname
	reshape wide v, i(CCode country year ) j(i) string
	***Label variables
	label variable vi120 "CO2 emissions (metric tons per capita)"
	label variable vi270 "Exports of goods and services (% of GDP)"
	label variable vi345 "GDP per capita, PPP (constant 2005 international $)"
	label variable vi518 "International migrant stock (% of population)"
	label variable vi519 "International migrant stock, total"
	label variable vi540 "Labor force with secondary education (% of total)"
	label variable vi543 "Labor force with tertiary education (% of total)"
	label variable vi552 "Land area (sq. km)"
	label variable vi632 "Military expenditure (% of GDP)"
	label variable vi712 "Net migration"
	label variable vi743 "Nitrous oxide emissions (thousand metric tons of CO2 equivalent)"
	label variable vi745 "Nitrous oxide emissions in industrial and energy processes (% of total nitrous oxide emissions)"
	label variable vi749 "Oil rents (% of GDP)"
	label variable vi799 "Population in largest city"
	label variable vi802 "Population in urban agglomerations of more than 1 million (% of total population)"
	label variable vi805 "Population, total"
	label variable vi970 "Road density (km of road per 100 sq. km of land area)"
	label variable vi1223 "Roads, goods transported (million ton-km)"
	label variable vi997 "School enrollment, secondary (% net)"
	label variable vi1053 "Surface area (sq. km)"
	label variable vi1145 "Urban population (% of total)"
	label variable vi1155 "Water pollution, chemical industry (% of total BOD emissions)"
	label variable vi1156 "Water pollution, clay and glass industry (% of total BOD emissions)"
	label variable vi1157 "Water pollution, food industry (% of total BOD emissions)"
	label variable vi1158 "Water pollution, metal industry (% of total BOD emissions)"
	label variable vi1159 "Water pollution, other industry (% of total BOD emissions)"
	label variable vi1160 "Water pollution, paper and pulp industry (% of total BOD emissions)"
	label variable vi1161 "Water pollution, textile industry (% of total BOD emissions)"
	label variable vi1162 "Water pollution, wood industry (% of total BOD emissions)"
	label variable vi568 "Literacy rate, adult total (% of people ages 15 and above)"
	label variable vi148 "Completeness of birth registration (%)"
	label variable vi1003 "School enrollment, tertiary (% gross)"
	ren vi1003 TertEduc

	gen Waterpollution= (vi1155+vi1156+vi1157+vi1158+vi1159+vi1160+vi1161+vi1162)/8
	label var Waterpollution "Average water pollution % of total Bod emissions"
	*Generates average yearly net migration
	bysort CCode:replace vi712 = vi712[_n+1]/5 if vi712 ==.
	bysort CCode:replace vi712 = vi712[_n+1] if vi712 ==.
	bysort CCode:replace vi712 = vi712[_n+1] if vi712 ==.
	bysort CCode:replace vi712 = vi712[_n+1] if vi712 ==.
	replace vi712 = vi712[_n+1] if vi518!=.
	bysort CCode:ipolate vi518 year,gen(MigrantShare) //linearly intrapolate the share of migrants
	label var MigrantShare "International migrant stock (% of population)"
	drop vi518
	bysort CCode:ipolate vi749  year,gen(OilRents) //linearly intrapolate the share of migrants
	label var OilRents "Oil rents (% of GDP)"
	*Generate relative share of population that lives in largest city
	gen PopLargestCity=vi799/ vi805
	label var PopLargestCity "% of population that lives in largest city"
	****
	save "bearbeitet\Worldbank.dta", replace
	clear
	******************************************************************************************************************************************
	*** Worldbank data, 2011, World Bank Analytical Country Classifications, by GNI per capita in US$ (Atlas methodology)
	*** Data  from the Worldbank that yields the respective Development rating in the specific year-
	***Key variable for merging: Three letter country code as "CCode" and "year"
	import excel "Country classifications WBtime varying.xls", sheet("Country Analytical History (2)") firstrow
	reshape long v, i(CCode) j(year)
	sort CCode year
	ren v WBCountryclass
	label var WBCountryclass "Development classification based on GNI per capita, time varying"
	save "bearbeitet\Country classifications.dta",replace
	clear

	*** Gassebner et al, ????, Data on various pollution measures, 1960 - 2010, but large gaps
	*** Data  
	***Key variable for merging: Three letter country code as "CCode" and "year"
	import excel "Pollutiondata.xls", sheet("BODpd") firstrow
	drop if CCode ==""
	reshape long v, i(CCode) j(year)
	sort CCode year
	ren v BODpd
	destring BODpd, gen(BOD)
	label var BOD "Organic water pollutant (BOD) emissions (kg per day)"
	drop BODpd A
	save "bearbeitet\BOD.dta",replace
	clear
	import excel "Pollutiondata.xls", sheet("Elecprod") firstrow
	drop if CCode ==""
	reshape long v, i(CCode) j(year)
	sort CCode year
	ren v ElectricyPro
	destring ElectricyPro,gen(ElectricyProd)
	drop A ElectricyPro
	label var ElectricyProd "Electricity production (kwh) "
	save "bearbeitet\ElectricityProd.dta",replace


	*** Harvard DemocracyTime-seriesDataset, 2009, Data for 1971-2007, but not all variables, 125-160 countries per year
	***Includes data on colonial origin, GDP from the World Bank and media circulation
	***Key variable for merging: Three letter country code as "CCode" and "year"
	use "Democracy_TimeSeries_Data_January2009_StataSE", clear
	*Keep possibly relevant variables, mostly regional dummies, constitutional origin, conflicts, political charactericstics and ethnic diversity, plus informational stage (internet e.g.)
	keep year Nation CCode  Britcol colony  POLstand ///
	fragment durable sf regtrans  CHEIBUB frac_eth frac_lan frac_rel  ELF Fearon  fedtype Admin Political   execage  govfrac delta19 ///
	 frac partyage auton muni state GDP_WB  delta26  polit01   interstate  Conflictups  FHPressCat Banksmediascale Africa Asia CEurope Nam Sam Scan MEast WEuro
	 replace FHPressCat=0 if FHPressCat==9
	sort CCode year
	*bysort CCode: gen Conflicts = Conflictups +Conflictups[_n-1] + Conflictups[_n-2]+Conflictups[_n-3]+Conflictups[_n-4]
	*label var Conflicts "No of interstate conflicts in the last 5 years"
	***
	save "bearbeitet\Democracy_TimeSeries.dta", replace
	******************************************************************************************************************************************

	***  Justina Fischer Decentralization data, ?, Data between 1985 and 1997, at most 6 observations per country, at most 36 per year, 250 observations overall
	*** Data on decentralization from Justina Fischer, quite old, but panel data including own-source local revenue
	***Some possible mistakes in the excel sheets, variable on urbanization could be appended as some data are there but not connected
	***Key variable for merging: Three letter country code as "CCode" and "year"
	clear
	import excel "Decentralization Data Justina.xlsx", sheet("Tabelle1") firstrow clear
	rename wbcode CCode
	***some labeling
	label variable slexgdp "Combined state and local expenditure/GDP"
	label variable slrevgdp "Combined state and local revenue/GDP"
	label variable sldefgdp "Combined state and local expenditure/Combined state, local, central expenditures"
	label variable sldefrev "Combined state and local revenue/Combined state, local, central revenue"
	label variable sldefgdp "ombined state, local, central expenditures"
	label variable slextot "Combined state and local expenditure/C"
	label variable slextot "Combined state and local expenditure/Combined state, local, central expenditures"
	label variable slrevtot "Combined state and local revenue/Combined state, local, central revenue"
	label variable sldefgdp ""
	label variable sldefrev ""
	label variable grgdp "Total grants/GDP"
	label variable grtotrev "Total grants/Combined state, local, central revenue"
	label variable grslrev "Total grants/Combined state, local revenue"
	label variable grcrev "Total grants/Central revenue"
	label variable oslrevtr `""Own-source" state and local revenue/Combined state, local, central revenue"'
	label variable oslrgdp `""Own-source" state and local revenue/GDP"'
	***Destring some variables
	 foreach var in pop cgdp open Governmentfractionalization {
					 replace  `var'="0" if  `var'=="na"	
					 replace  `var'="0" if  `var'==" "	
					destring `var',gen( "`var'_1") force
					replace `var'_1=. if `var'_1==0
					rename `var' `var'_2
					rename `var'_1 `var'
					drop `var'_2
					}
	save "bearbeitet\Decentralization Data Justina.dta", replace
	******************************************************************************************************************************************
	*** Axel Dreher and Justina Fischer decentralization data, 2008, 676 observations, panel with several countries and years, 1990-2008
	*** Data on decentralization, some values are computed, ask Axel for details
	***Key variable for merging: Three letter country code as "CCode" and "year"
	clear 
	import excel "Dezentralisierung Dreher and Fischer.xls", sheet("Tabelle3") firstrow
	drop K
	*Some labeling and renaming
	rename Dez3subfedexpgrantsge Dez3
	rename Dez4subfedexpgrantstoge  Dez4
	rename Dez1subfedexpgengovexp Dez1
	rename General_Expensecomputed General_Expenses_Dreher
	rename General_Grantscomputed General_Grants_Dreher
	rename General_To_general_government_un government_units_Dreher
	*******
	********Axel fragen ob 2009/2010 von Eurostat auffllen. Wieso fehlen z.b. Belgien die neuen Daten komplett
	save "bearbeitet\Dez Dreher Fischer.dta", replace
	************************************************************************************************************************+

	*** OECD, 2012, OECD member states
	*** Data on  fiscal decentralization, more values for revenues than for expenditures, distinguish between central, regional and local
	***Key variable for merging: Three letter country code as "CCode" and "year"
	*****At first data on expenditure
	use "OECDexpenditures.dta", clear
	****reshape
	reshape long tax, i( country ccode var) j(year)
	drop var
	reshape wide tax, i( ccode year) j( var2 ) string
	********Rename variables
	rename taxg2 expcentral_OECD
	rename taxg1 expGeneral_OECD
	rename taxg3 expstate_OECD
	rename taxg4 explocal_OECD
	rename ccode CCode
	label variable year "year of OECD data"
	drop country
	***************
	save "bearbeitet\OECDexpenditures.dta", replace
	*********
	clear
	use "OECDrevenues.dta", clear
	reshape long tax, i( country ccode variable) j(year)
	drop variable country
	reshape wide tax, i(ccode year) j(var4) string
	********Rename variables
	rename taxr2 taxcentral_OECD
	rename taxr1 taxGeneral_OECD
	rename taxr3 taxstate_OECD
	rename taxr4 taxlocal_OECD
	rename ccode CCode
	label variable year "year of OECD data"
	***************
	save "bearbeitet\OECDrevenues.dta", replace
	****
	****Merge both OECD files
	***there are far more observations on the revenues than on the expenditures
	merge 1:1 CCode year using  "bearbeitet\OECDexpenditures.dta"
	drop _merge
	save "bearbeitet\OECDFiscalDec.dta", replace
	****************************************************************************************************************

	*** ICRG, 2009
	*** Data on perceptions of risk, mainly external conflicts
	***Key variable for merging: Three letter country code as "CCode" and "year"

	import excel "ICRG Political Risk 1984-2009 with codes.xls", sheet("External Conflict") firstrow clear
	*ren B CCode
	drop if CCode==""
	destring VE2007,gen(VE2007a) force
	drop VE2007
	ren VE2007a VE2007
	reshape long VE,i(Country CCode) j(year)
	sort CCode year
	ren VE RiskofExternalConflicts
	label var RiskofExternalConflicts "RiskofExternalConflicts"

	save "bearbeitet\ICRG1.dta", replace

	*** Data on perceptions of Ethnic Tensions

	import excel "ICRG Political Risk 1984-2009 with codes.xls", sheet("Ethnic Tensions") firstrow clear
	ren B CCode
	drop if CCode==""
	destring VE2007,gen(VE2007a) force
	drop VE2007
	ren VE2007a VE2007
	reshape long VE,i(Country CCode) j(year)
	sort CCode year
	ren VE EthnicTensions
	label var EthnicTensions "Ethnic Tensions from ICRG"
	save "bearbeitet\ICRG2.dta", replace
	*** Data on perceptions of government stability

	import excel "ICRG Political Risk 1984-2009 with codes.xls", sheet("Government Stability") firstrow clear
	ren B CCode
	drop if CCode==""
	destring VE2007,gen(VE2007a) force
	drop VE2007
	ren VE2007a VE2007
	reshape long VE,i(Country CCode) j(year)
	sort CCode year
	ren VE GovernmentStability
	label var GovernmentStability "GovernmentStability"
	save "bearbeitet\ICRG3.dta", replace

	clear
	import excel "ICRG Political Risk 1984-2009 with codes.xls", sheet("Corruption") firstrow clear
	*ren B CCode
	drop if CCode==""
	destring VE2007,gen(VE2007a) force
	drop VE2007
	ren VE2007a VE2007
	reshape long VE,i(Country CCode) j(year)
	sort CCode year
	ren VE Corruption
	label var Corruption "Corruption from ICRG"
	save "bearbeitet\ICRG4.dta", replace

	use "bearbeitet\ICRG1.dta",clear
	sort CCode year
	merge CCode year using "bearbeitet\ICRG2.dta"
	drop _merge
	sort CCode year
	merge CCode year using "bearbeitet\ICRG3.dta"
	drop _merge
	merge m:m CCode year using "bearbeitet\ICRG4.dta"
	drop _merge
	save "bearbeitet\ICRG.dta", replace

*** Freedom House Data, accessed online 09.10.2012, at http://www.freedomhouse.org/report-types/freedom-press
	*** Data on Freedom of the press, old data recoded as: (F =25, PF=50, NF=75), Print Freedom chosen
	***Key variable for merging: Three letter country code as "CCode" and "year"
	use "Freedom of the Press.dta",clear
	drop if CCode=="."
	reshape long v, i(CCode) j(year)
	ren v PressFreedom
	label var PressFreedom "Freedom House Press Freedom"
	save "bearbeitet\Freedom of the Press.dta",replace
	
	*** PWT7.1, accessed online 24.09.2012, at ...website...
	*** Data on PPP adjusted GDP and on openness
	***Key variable for merging: Three letter country code as "CCode" and "year"

	insheet using "PWT7.1.csv", nodouble comma clear
	ren year Year
	destring Year,gen(year) force
	drop Year
	label var openk "Openness at 2005 constant prices (%)"
	label var rgdpch "PPP Converted GDP Per Capita (Chain Series), at 2005 constant prices"
	label var rgdpl "PPP Converted GDP Per Capita (Laspeyres)"
	ren isocode CCode
	keep CCode year pop rgdpl rgdpch openk
	sort CCode year
	gen logGDP=log(rgdpl)
	label var logGDP "log PPP Converted GDP Per Capita"
	save"bearbeitet\PWT.dta",replace

	*** World Telecommunications /ICT Indicators Database
	*** Data on technology and telecommunication
	***Key variable for merging: Three letter country code as "CCode" and "year"
	use "ICTold.dta",clear
	ren country_code CCode
	reshape long _,i(CCode series_name series_code  ) j (year)
	drop country_name series_name varname
	ren _ Var

	reshape wide Var,i(CCode  year) j(series_code) string
	label var VarI143 "Faults per 100 fixed telephone lines per year "
	label var VarI91 "Fixed telephone lines per 100 inhabitants "
	label var VarI152B "Monthly subscription for business telephone service (US$) "
	label var VarI141 "Percentage of fixed telephone faults cleared by next working day "
	label var VarXHH "Percentage of households with a fixed line telephone "
	label var VarXH "Percentage of households with a radio "
	label var VarI1163 "Percentage of localities with telephone service "

	save "bearbeitet\ICT.dta", replace



	*******************************************************************************************************************
	************* PART 2: merge databases
	*******************************************************************************************************************

	*** Use Treisman Cross-Section data, merge them with the DELF and World Bank data
	use "bearbeitet\Treisman.dta", clear
	***Merge with DELF data
	merge m:m CCode using "bearbeitet\DELF Country data.dta"
	drop _merge
	****Add Worldbank data
	merge m:m CCode year using "bearbeitet\Worldbank.dta"
	drop if _merge!=3
	drop _merge
	**Add colonial origin from Fisman
	merge m:m CCode using "bearbeitet\Fisman.dta"
	drop if _merge!=3
	drop _merge
	*** Add democracy data
	merge m:m CCode year using "bearbeitet\Democracy_TimeSeries.dta"
	drop if _merge!=3
	drop _merge
	saveold "bearbeitet\Treisman complete.dta",replace
	****************************************************************************************************************
	***Panel OECD Data
	use "bearbeitet\OECDFiscalDec.dta", clear
	***Merge with DELF data
	merge m:m CCode using "bearbeitet\DELF Country data.dta"
	drop if _merge==2
	drop _merge
	****Add Worldbank data
	merge m:m CCode year using "bearbeitet\Worldbank.dta"
	drop if _merge==2
	drop _merge
	**Add colonial origin from Fisman
	merge m:m CCode using "bearbeitet\Fisman.dta"
	drop if _merge==2
	drop _merge
	*** Add Harvard democracy data
	merge m:m CCode year using "bearbeitet\Democracy_TimeSeries.dta"
	drop if _merge==2
	drop _merge
	**
	saveold "bearbeitet\OECDFiscalDec complete.dta",replace
	****************************************************************************************************************
	*IMF Government Finance data
	use "bearbeitet\IMF_GFS.dta",clear
	merge m:m CCode year using "bearbeitet\Worldbank.dta"
	drop if _merge==2
	drop _merge
	merge m:m CCode  using "bearbeitet\DELF Country data.dta"
	drop if _merge==2
	drop _merge
	merge m:m CCode  using "bearbeitet\Democracy_TimeSeries.dta"
	encode CCode,gen(ccode) label(CCode)
	* Problem xtset reports that there are repeated time values within the panel, the country Serbia with the CCode "SRB" is in their twice	each year (most years)
	sort CCode year 
	bysort CCode year : gen no=[_n] if CCode=="SRB"
	drop if no==2
	drop no // Try to solve problem
	drop if CCode=="AGO" &year==1980&Africa==.
	drop if CCode=="BEN" &year==1971&delta19==.
	drop Africa Asia CEurope Nam Sam Scan MEast WEuro
	drop delta19
	drop if _merge==2
	drop _merge
	merge m:m CCode  using "bearbeitet\Treisman.dta"
	drop if _merge==2
	drop _merge
	bysort CCode:egen YearConstitution=mean( year_of_const)
	bysort CCode: gen AgeConstitution =year- year_of_const
	label var AgeConstitution "Years since the constitution was established"
	merge m:m CCode year using "bearbeitet\ICRG.dta"
	drop if _merge==2
	drop _merge

	merge m:m CCode year using "bearbeitet\PWT.dta"
	drop if _merge==2
	drop _merge

	merge m:m CCode year using "bearbeitet\ICT.dta"
	drop if _merge==2
	drop _merge

	merge m:m CCode year using "bearbeitet\missing_4.dta"
	drop if _merge==2
	drop _merge

	merge m:m CCode year using "bearbeitet\missing.dta"
	drop if _merge==2
	drop _merge

	merge m:m CCode year using "bearbeitet\Country classifications.dta"
	drop if _merge==2
	drop _merge

	merge m:m CCode year using  "bearbeitet\BOD.dta"
	drop if _merge==2
	drop _merge

	merge m:m CCode year using  "bearbeitet\ElectricityProd.dta"
	drop if _merge==2
	drop _merge

	merge m:m CCode year using  "bearbeitet\Freedom of the Press.dta"
	drop if _merge==2
	drop _merge
	
	xtset ccode year

	bysort CCode:ipolate durable year,gen(RegimeDurability) epolate
	replace RegimeDurability=0 if RegimeDurability<=0
	tab colony,gen(Col)
	replace sf =0 if sf==.
	ren sf CollapseDummy
	bysort CCode:ipolate partyage year,gen(Partyage) epolate
	drop partyage
	ren Partyage partyage
	replace partyage=. if partyage<=0
	sort CCode year
	foreach var of varlist frac_eth frac_lan frac_rel  ELF auton muni state Fearon  Admin Political{
	*by CCode: carryforward `var',replace
	by CCode: carryforward `var',replace 
	gsort CCode -year
	by CCode: carryforward `var',replace 
	}
	sort CCode year
	gen ExtConflict=0
replace ExtConflict=1 if interstate[_n-1]==1
replace ExtConflict=1 if interstate[_n-2]==1
replace ExtConflict=1 if interstate[_n-3]==1
replace ExtConflict=1 if interstate[_n-4]==1
replace ExtConflict=1 if interstate[_n-5]==1
replace ExtConflict=1 if interstate[_n]==1
replace ExtConflict=1 if interstate[_n-6]==1
replace ExtConflict=1 if interstate[_n-7]==1
replace ExtConflict=1 if interstate[_n-8]==1
replace ExtConflict=1 if interstate[_n-9]==1
label var ExtConflict "Interstate military conflict in the last 10 years"

gen period3=0 
forvalues i = 1(1)15 {
replace period3=`i' if year<=1971+3*`i' & period3==0
}

gen period5=0 
forvalues i = 1(1)15 {
replace period5=`i' if year<=1971+5*`i' & period5==0
}
drop if year==2012 //Not enough variables in that year
gen period10=0 
forvalues i = 1(1)5 {
replace period10=`i' if year<=1971+10*`i' & period10==0
}


	order period3 period5 period10,after(year)
	ren vi1145 UrbanPop
	ren vi712 NetMigr
	ren vi552 LandArea
	ren vi805 Pop
	ren vi799 PopLCity
	ren vi120 CO2
	ren VarI91 InfoTransmission

	tab fearonregion,gen(Region)
	sort CCode year
	save "bearbeitet\Decentralization.dta",replace
*********************************************************************************************************************************************************

use "bearbeitet\Decentralization.dta",clear
*Summary statistics
xtsum Sub_Exp SubRev VerIm AllTaxes Employees


foreach Yvar in  Sub_Exp SubRev  {
 
correl `Yvar' RiskofExternalConflicts EthnicTensions GovernmentStability logGDP openk  PopLargestCity    MigrantShare UrbanPop NetMigr LandArea  Pop PopLCity CO2 InfoTransmission OilRents
correl `Yvar' delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel  frac partyage missing_4 missing  Conflictups FHPressCat Corruption 
*delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel ELF frac partyage
xtreg `Yvar' Conflictups EthnicTensions GovernmentStability logGDP openk    NetMigr UrbanPop  LandArea  Pop  CO2 InfoTransmission OilRents missing,fe
}



xtsum  RiskofExternalConflicts EthnicTensions GovernmentStability logGDP openk  PopLargestCity    MigrantShare UrbanPop NetMigr LandArea  Pop PopLCity CO2 InfoTransmission OilRents ///
delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel  frac partyage missing_4 missing  Conflictups FHPressCat Corruption
des RiskofExternalConflicts EthnicTensions GovernmentStability logGDP openk  PopLargestCity    MigrantShare UrbanPop NetMigr LandArea  Pop PopLCity CO2 InfoTransmission OilRents ///
delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel  frac partyage missing_4 missing  Conflictups FHPressCat Corruption
/*
*List of x-variables


              storage  display     value
variable name   type   format      label      variable label
--------------------------------------------------------------------------------------------------------------------------------------------------------
RiskofExterna~s double %10.0g                 RiskofExternalConflicts
EthnicTensions  double %10.0g                 Ethnic Tensions from ICRG
GovernmentSta~y double %10.0g                 GovernmentStability
logGDP          float  %9.0g                  log PPP Converted GDP Per Capita
openk           float  %9.0g                  Openness at 2005 constant prices (%)
PopLargestCity  float  %9.0g                  % of population that lives in largest city
MigrantShare    double %10.0g                 International migrant stock (% of population)
UrbanPop        double %8.0g                  Urban population (% of total)
NetMigr         double %8.0g                  Net migration
LandArea        double %8.0g                  Land area (sq. km)
Pop             double %8.0g                  Population, total
PopLCity        double %8.0g                  Population in largest city
CO2             double %8.0g                  CO2 emissions (metric tons per capita)
InfoTransmission          float  %9.0g                  Fixed telephone lines per 100 inhabitants
OilRents        double %10.0g                 Oil rents (% of GDP)
delf            float  %9.0g                  DELF (composite)
delf_Geo        float  %9.0g                * DELF_geo_detailed
delf_language   float  %9.0g                  DELF_Language
delf_ethnic     float  %9.0g                  DELF_Ethnic
delf_religion   float  %9.0g                  DELF_Religion
frac_eth        double %10.0g               * Ethnic factionlization (combined linguistic and racial) (Alesina 2002)
frac_lan        double %10.0g               * Linguistic fractionalization (Alesina 2002)
frac_rel        double %10.0g               * Religious fractionalization (Alesina 2002)
frac            double %10.0g                 Total fractionalization (chance that two random draws will produce legislators f
partyage        double %10.0g                 
missing_4       float  %9.0g                  Missing WDI data based on four indicators
missing         float  %9.0g                  Missing WDI data based on four indicators
Conflictups     double %10.0g                 Number of conflicts (UCDP/PRIO)
FHPressCat      double %10.0g      FHPressCat
                                              FH PressFreedom 3-pt Categories 1980_2006
Corruption      double %10.0g                 Corruption from ICRG




des vi1145  vi518  vi712 vi540 vi552 vi749 vi805  vi799 vi543 vi120 vi745 vi743  vi970  RiskofExternalConflicts ///
EthnicTensions GovernmentStability rgdpl openk VarI91 delf delf_Geo delf_language delf_ethnic delf_religion 

frac_eth frac_lan frac_rel elf

*/
clear

*********************************************************************************************************************************************************************************************
*********************************************************************************************************************************************************************************************
****************************************************Analysis*********************************************************************************************************************************
*********************************************************************************************************************************************************************************************
*********************************************************************************************************************************************************************************************

*Output tables separated for 1year, 5 year and 10 year samples, named period
*1 and 5 years as panels, 10 years as 4 cross-sections

*Variable list: CCOde year CHEIBUB colony RiskofExternalConflicts EthnicTensions GovernmentStability logGDP openk  PopLargestCity    MigrantShare UrbanPop NetMigr LandArea  Pop PopLCity ///
*CO2 InfoTransmission OilRents delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel  frac partyage missing_4 missing  Conflictups PressFreedom Corruption TertEduc
*Region1 Region2 Region3 Region4 Region5 Region6 ExtConflict


use "bearbeitet\Decentralization.dta",clear
 xtset ccode year
preserve
foreach YVar of varlist Sub_Exp SubRev VerIm AllTaxes Employees  {
xtreg `YVar'  l.(logGDP  LandArea  Pop UrbanPop openk  CHEIBUB D_EurostatExp) ,fe
est store Table11_FE`YVar' 
xtreg `YVar'  l.(logGDP  LandArea  Pop UrbanPop openk  CHEIBUB D_EurostatExp RiskofExternalConflicts  OilRents   missing   InfoTransmission  CO2   TertEduc PressFreedom)                 ,fe
est store Table12_FE`YVar' 
xtreg `YVar'  l.(logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  D_EurostatExp EthnicTensions NetMigr GovernmentStability Corruption) ,fe
est store Table13_FE`YVar' 
xtreg `YVar'  l.(logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  D_EurostatExp RiskofExternalConflicts  OilRents   missing    InfoTransmission   CO2   TertEduc PressFreedom EthnicTensions ///
NetMigr GovernmentStability Corruption) ,fe
est store Table14_FE`YVar' 




collapse ccode Sub_Exp SubRev VerIm AllTaxes Employees CHEIBUB Col* colony RiskofExternalConflicts EthnicTensions GovernmentStability logGDP openk  PopLargestCity    MigrantShare ///
UrbanPop NetMigr LandArea  Pop PopLCity CO2 InfoTransmission OilRents delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel  frac   missing_4  ///
missing  ExtConflict Corruption TertEduc Region1 Region2 Region3 Region4 Region5 Region6 fedelupd PressFreedom RegimeDurability, by(CCode period5)
*Correct Colonial Dummies
foreach Col in Col1 Col2 Col3 Col4 Col5 Col6 Col7 Col8 Col9 CHEIBUB{
replace `Col'=0 if `Col'<=0.4
replace `Col'=1 if `Col'>=0.6
}

xtset ccode period5 
xtreg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB   ,fe
est store Table21_FE`YVar' 
xtreg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB   RiskofExternalConflicts  OilRents   missing   InfoTransmission  CO2   TertEduc   PressFreedom           ,fe
est store Table22_FE`YVar' 
xtreg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  EthnicTensions NetMigr GovernmentStability Corruption,fe
est store Table23_FE`YVar' 
xtreg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  RiskofExternalConflicts OilRents missing   InfoTransmission CO2 TertEduc PressFreedom EthnicTensions ///
NetMigr GovernmentStability ,fe
est store Table24_FE`YVar' 


***************5 yearly with OLS and regional dummies (asia is reference group)
reg `YVar' logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  Region2 Region3 Region4 Region5 Region6 ,robust
est store Table31_OLS`YVar' 
reg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB   RiskofExternalConflicts  OilRents   missing   InfoTransmission  CO2   TertEduc  PressFreedom  Region2 Region3 Region4 Region5 Region6  ///
    ,robust
est store Table32_OLS`YVar' 
reg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  EthnicTensions NetMigr GovernmentStability Corruption  Region2 Region3 Region4 Region5 Region6 ///
  ,robust
est store Table33_OLS`YVar' 
reg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  EthnicTensions NetMigr GovernmentStability  frac_eth frac_lan frac_rel Region2 Region3 Region4 Region5 Region6 ///
  ,robust
est store Table34_OLS`YVar' 
reg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  RiskofExternalConflicts   OilRents     missing    InfoTransmission   CO2   TertEduc PressFreedom EthnicTensions ///
NetMigr GovernmentStability Corruption Region2 Region3 Region4 Region5 Region6   ,robust
est store Table35_OLS`YVar' 


 
restore, preserve
*******************10 yearly********************************************************************************
collapse ccode Sub_Exp SubRev VerIm AllTaxes Employees CHEIBUB Col* colony RiskofExternalConflicts EthnicTensions GovernmentStability logGDP openk  PopLargestCity    MigrantShare ///
UrbanPop NetMigr LandArea  Pop PopLCity CO2 InfoTransmission OilRents delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel  frac   missing_4 ///
missing  ExtConflict Corruption TertEduc Region1 Region2 Region3 Region4 Region5 Region6 fedelupd PressFreedom RegimeDurability, by(CCode period10)
foreach Col in Col1 Col2 Col3 Col4 Col5 Col6 Col7 Col8 Col9 CHEIBUB{
replace `Col'=0 if `Col'<=0.4
replace `Col'=1 if `Col'>=0.6
}

xtset ccode period10 

***10 yearly with fixed effects
xtreg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB   ,fe
est store Table41_FE`YVar' 
xtreg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB   RiskofExternalConflicts  OilRents   missing   InfoTransmission  CO2   TertEduc  PressFreedom                ,fe
est store Table42_FE`YVar' 
xtreg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  delf NetMigr RegimeDurability Corruption,fe
est store Table43_FE`YVar' 
xtreg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  RiskofExternalConflicts   OilRents   missing    InfoTransmission   CO2   TertEduc PressFreedom ///
EthnicTensions NetMigr GovernmentStability Corruption,fe
est store Table44_FE`YVar' 

*10 yearly with OLS and regional dummies
reg `YVar' logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  Region2 Region3 Region4 Region5 Region6 ,robust
est store Table51_OLS`YVar' 
reg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  RiskofExternalConflicts  OilRents   missing   InfoTransmission  CO2   TertEduc PressFreedom  Region2 Region3 Region4 Region5 Region6  ///
     ,robust
est store Table52_OLS`YVar' 
reg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  EthnicTensions NetMigr GovernmentStability Corruption Region2 Region3 Region4 Region5 Region6 ///
  ,robust
est store Table53_OLS`YVar' 
reg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  EthnicTensions NetMigr GovernmentStability  frac_eth frac_lan frac_rel Region2 Region3 Region4 Region5 Region6 ///
  ,robust
est store Table54_OLS`YVar' 
reg `YVar'  logGDP  LandArea  Pop UrbanPop openk  CHEIBUB  RiskofExternalConflicts   OilRents   missing    InfoTransmission   CO2   TertEduc PressFreedom EthnicTensions ///
NetMigr GovernmentStability Corruption PressFreedom  Region2 Region3 Region4 Region5 Region6    ,robust
est store Table55_OLS`YVar' 

restore, preserve

/*
sort CCode period5
foreach Mean in RiskofExternalConflicts EthnicTensions GovernmentStability logGDP openk VarI91 vi1145 PopLargestCity  vi805 vi552 vi120 vi749 MigrantShare vi712 vi543 vi540 missing_4 missing ///
delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel ELF frac partyage vi1003 Conflictups FHPressCat Corruption {
by CCode period5: egen M5`Mean'=mean(`Mean')
}
by CCode period5:gen count=[_n]
drop if count!=1

*Baseline 5 year panel

foreach 
restore, preserve

sort CCode period10
foreach Mean in RiskofExternalConflicts EthnicTensions GovernmentStability logGDP openk VarI91 vi1145 PopLargestCity  vi805 vi552 vi120 vi749 MigrantShare vi712 vi543 vi540 missing_4 missing ///
delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel ELF frac partyage vi1003 Conflictups FHPressCat Corruption {
by CCode period10: egen M5`Mean'=mean(`Mean')
}
by CCode period10:gen count=[_n]
drop if count!=1



foreach Yvar in  Sub_Exp SubRev VerIm AllTaxes Employees  {
*/



estout 			Table11_FE`YVar' Table12_FE`YVar' Table13_FE`YVar' Table14_FE`YVar' using "tables\table1`YVar'.txt",replace ///
				title("Yearly data with fixed effects, `YVar'") delimiter(_tab) noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par vacant("-") label(Std. err.))) ) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) ///
								stats(r2_a N , labels("Adj. R-Squared" "Number of Cases") fmt(2) ) 
								
								
*5 yearly with fixed effects
estout 			Table21_FE`YVar' Table22_FE`YVar' Table23_FE`YVar' Table24_FE`YVar' using "tables\table2`YVar'.txt",replace ///
				title("5-yearly data with fixed effects, `YVar'") delimiter(_tab) noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par vacant("-") label(Std. err.))) ) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) ///
								stats(r2_a N , labels("Adj. R-Squared" "Number of Cases") fmt(2)) 
								
*5 yearly with OLS and regional dummies
estout 			Table31_OLS`YVar' Table32_OLS`YVar' Table33_OLS`YVar'  Table34_OLS`YVar' Table35_OLS`YVar'   using "tables\table3`YVar'.txt",replace ///
				title("5-yearly data with region dummies, `YVar'") delimiter(_tab) noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par vacant("-") label(Std. err.))) ) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) ///
								stats(r2_a N , labels("Adj. R-Squared" "Number of Cases") fmt(2)) 												

*10 yearly with fixed effects
estout 			Table41_FE`YVar' Table42_FE`YVar' Table43_FE`YVar'  Table44_FE`YVar'   using "tables\table4`YVar'.txt",replace ///
				title("10-yearly data with fixed effects") delimiter(_tab) noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par vacant("-") label(Std. err.))) ) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) ///
								stats(r2_a N , labels("Adj. R-Squared" "Number of Cases") fmt(2)) 												

*10 yearly with fixed effects
estout 			Table51_OLS`YVar' Table52_OLS`YVar' Table53_OLS`YVar'  Table54_OLS`YVar' Table55_OLS`YVar'   using "tables\table5`YVar'.txt",replace ///
				title("10-yearly data with region dummies, `YVar'") delimiter(_tab) noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par vacant("-") label(Std. err.))) ) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) ///
								stats(r2_a N , labels("Adj. R-Squared" "Number of Cases") fmt(2)) 	
														
}












*log close

















